==> hazelcast-all-4.1-sources.jar: com/hazelcast/org/codehaus/commons/compiler/LocatedException.java <==

/*
 * Janino - An embedded Java[TM] com.hazelcast.com.iler
 *
 * Copyright (c) 2001-2010 Arno Unkrig. All rights reserved.
 * Copyright (c) 2015-2016 TIBCO Software Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *    1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
 *       following disclaimer.
 *    2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *       following disclaimer in the documentation and/or other materials provided with the distribution.
 *    3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote
 *       products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.hazelcast.org.codehaus.com.hazelcast.com.ons.com.hazelcast.com.iler;

import com.hazelcast.org.codehaus.com.hazelcast.com.ons.nullanalysis.Nullable;

/**
 * An {@link Exception} that is associated with an optional {@link Location} in a source file.
 */
public
class LocatedException extends Exception {

    @Nullable private final Location optionalLocation;

    public
    LocatedException(String message, @Nullable Location optionalLocation) {
        super(message);
        this.optionalLocation = optionalLocation;
    }

    public
    LocatedException(String message, @Nullable Location optionalLocation, @Nullable Throwable optionalCause) {
        super(message, optionalCause);
        this.optionalLocation = optionalLocation;
    }

    /**
     * Returns the message specified at creation time, preceeded with nicely formatted location information (if any).
     */
    @Override public String
    getMessage() {
        return (
            this.optionalLocation != null
            ? this.optionalLocation.toString() + ": " + super.getMessage()
            : super.getMessage()
        );
    }

    /**
     * @return The {@link Location} specified at construction time (may be {@code null})
     */
    @Nullable public Location
    getLocation() { return this.optionalLocation; }
}

==> hazelcast-all-4.1.10-sources.jar: com/hazelcast/org/codehaus/commons/compiler/LocatedException.java <==

/*
 * Janino - An embedded Java[TM] compiler
 *
 * Copyright (c) 2001-2010 Arno Unkrig. All rights reserved.
 * Copyright (c) 2015-2016 TIBCO Software Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *    1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
 *       following disclaimer.
 *    2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *       following disclaimer in the documentation and/or other materials provided with the distribution.
 *    3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote
 *       products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.hazelcast.org.codehaus.commons.compiler;

import com.hazelcast.org.codehaus.commons.nullanalysis.Nullable;

/**
 * An {@link Exception} that is associated with an optional {@link Location} in a source file.
 */
public
class LocatedException extends Exception {

    @Nullable private final Location optionalLocation;

    public
    LocatedException(String message, @Nullable Location optionalLocation) {
        super(message);
        this.optionalLocation = optionalLocation;
    }

    public
    LocatedException(String message, @Nullable Location optionalLocation, @Nullable Throwable optionalCause) {
        super(message, optionalCause);
        this.optionalLocation = optionalLocation;
    }

    /**
     * Returns the message specified at creation time, preceeded with nicely formatted location information (if any).
     */
    @Override public String
    getMessage() {
        return (
            this.optionalLocation != null
            ? this.optionalLocation.toString() + ": " + super.getMessage()
            : super.getMessage()
        );
    }

    /**
     * @return The {@link Location} specified at construction time (may be {@code null})
     */
    @Nullable public Location
    getLocation() { return this.optionalLocation; }
}
